bayespy.inference.vmp.transformations.RotateVaryingMarkovChain
==============================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. autoclass:: RotateVaryingMarkovChain

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~RotateVaryingMarkovChain.__init__
      ~RotateVaryingMarkovChain.bound
      ~RotateVaryingMarkovChain.get_bound_terms
      ~RotateVaryingMarkovChain.nodes
      ~RotateVaryingMarkovChain.rotate
      ~RotateVaryingMarkovChain.setup
   
   

   
   
   